==> nextcloud-app-calendar-1%3A2.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es_CR.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "Share link" : "Compartir liga",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "can edit" : "puede editar",
    "New calendar" : "Nuevo calendario",
    "Filename" : "Nombre del archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "Show week numbers" : "Mostrar número de semana",
    "Settings & import" : "Configuraciones & importar",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "Unknown" : "Desconocido",
    "All day" : "Todo el día",
    "from" : "de",
    "to" : "para",
    "never" : "nunca",
    "after" : "después",
    "Repeat" : "Repetir",
    "Monday" : "Lunes",
    "Summary" : "Resumen",
    "More" : "Más",
    "Save" : "Guardar",
    "Update" : "Actualizar",
    "Personal" : "Personal",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Activity" : "Actividad",
    "Close" : "Cerrar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativo",
    "Cancelled" : "Cancelado",
    "Categories" : "Categorías",
    "Mail" : "Correo",
    "Play" : "Reproducir",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A2.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es_CR.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Calendar" : "Calendario",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "List" : "Lista",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "Share link" : "Compartir liga",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "can edit" : "puede editar",
    "New calendar" : "Nuevo calendario",
    "Filename" : "Nombre del archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "or" : "o",
    "Actions" : "Acciones",
    "Show week numbers" : "Mostrar número de semana",
    "Settings & import" : "Configuraciones & importar",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "Unknown" : "Desconocido",
    "All day" : "Todo el día",
    "never" : "nunca",
    "after" : "después",
    "Repeat" : "Repetir",
    "Monday" : "Lunes",
    "Summary" : "Resumen",
    "More" : "Más",
    "Save" : "Guardar",
    "Update" : "Actualizar",
    "Personal" : "Personal",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Close" : "Cerrar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "next year" : "próximo año",
    "today" : "hoy",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativo",
    "Categories" : "Categorías",
    "Mail" : "Correo",
    "Play" : "Reproducir",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");
